@@ -13,6 +13,6 @@
 
 from __future__ import print_function
 
-from printer import print_json
+from printer import print_json, main as _printer_main
 from diff import diff
-from patch import patch
+from patch import patch, main as _patch_main
